@@ -1,5 +1,4 @@
-from .normalizer import Normalizer
 from .sentence_splitter import SentenceSplitter
+from .normalizer import Normalizer
 
-
-__all__ = ['Normalizer', 'SentenceSplitter']
+__all__ = ['SentenceSplitter', 'Normalizer']
\ No newline at end of file
